@@ -10,15 +10,23 @@ Version 2.0.0 adds support for:
 - User team context
 - MongoDB integration for entitlements data
 - Entitlement-based authorization decorators
+
+Version 2.3.0 adds stateless team context (backwards compatible):
+- available_teams[] list alongside current_team_id (deprecated)
+- Single aggregation query instead of 3-4 queries for validation
+- 30-50ms latency reduction
+- Team access validation decorator
 """
 
 from .decorators import (
     require_all_entitlements,
     require_any_entitlement,
     require_entitlement,
+    require_team_access,
 )
 from .middleware import create_auth_dependency, verify_auth, verify_auth_optional
 from .models.context import StytchContext
+from .models.team import TeamInfo
 from .utils.exceptions import (
     AuthenticationError,
     StytchAPIError,
@@ -26,7 +34,7 @@ from .utils.exceptions import (
     TokenVerificationError,
 )
 
-__version__ = "2.2.1"
+__version__ = "2.3.0"
 __all__ = [
     # Core authentication
     "verify_auth",
@@ -36,8 +44,11 @@ __all__ = [
     "require_entitlement",
     "require_any_entitlement",
     "require_all_entitlements",
+    # Team access decorator (v2.3.0+)
+    "require_team_access",
     # Models
     "StytchContext",
+    "TeamInfo",
     # Exceptions
     "AuthenticationError",
     "TokenExtractionError",
