@@ -15,6 +15,7 @@ import stytch
 from ..cache.redis_client import redis_client
 from ..db.entitlements_loader import entitlements_loader
 from ..models.context import StytchContext
+from ..models.team import TeamInfo
 from ..utils.config import settings
 from ..utils.exceptions import StytchAPIError, TokenVerificationError
 from ..utils.logger import logger
@@ -172,7 +173,7 @@ class StytchVerifier:
                 )
 
             # Handle different response formats from Stytch SDK
-            session_data = None
+            session_data: Optional[Dict[str, Any]] = None
 
             # First, try to convert response to string to check if it's JSON
             response_str = str(response)
@@ -180,17 +181,19 @@ class StytchVerifier:
             if hasattr(response, "json") and callable(response.json):
                 # Response is an HTTP response object
                 try:
-                    session_data = response.json()
+                    json_result = response.json()
 
                     # Check if .json() returned a string instead of parsed data
-                    if isinstance(session_data, str):
-                        session_data = json.loads(session_data)
+                    if isinstance(json_result, str):
+                        session_data = json.loads(json_result)
+                    elif isinstance(json_result, dict):  # type: ignore[unreachable]
+                        session_data = json_result
 
                 except Exception:
                     session_data = None
-            elif isinstance(response, dict):
+            elif isinstance(response, dict):  # type: ignore[unreachable]
                 # Response is already a dictionary
-                session_data = response
+                session_data = response  # type: ignore[unreachable]
             elif hasattr(response, "member_session") and hasattr(response, "member"):
                 # Modern Stytch response object with direct attributes
                 member_session = getattr(response, "member_session", {})
@@ -223,9 +226,9 @@ class StytchVerifier:
                         "Invalid JSON response from Stytch API",
                         api_response={"error": f"JSON parse error: {str(e)}"},
                     )
-            elif isinstance(response, str):
+            elif isinstance(response, str):  # type: ignore[unreachable]
                 # Response is a JSON string - parse it
-                try:
+                try:  # type: ignore[unreachable]
                     session_data = json.loads(response)
                 except json.JSONDecodeError as e:
                     raise StytchAPIError(
@@ -353,13 +356,13 @@ class StytchVerifier:
         # Load fresh team context from MongoDB (not cached)
         member_id = cached_data["member_id"]
         organization_id = cached_data.get("organization_id")  # Get org ID from cache
-        team_context = {}
-        if settings.mongodb_uri and member_id:
+        team_context: Dict[str, Any] = {}
+        if settings.mongodb_uri and member_id and organization_id:
             try:
-                # Pass organization_id for multi-org user support
+                # Pass organization_id for multi-org user support (must be str, not None)
                 team_context = (
                     await entitlements_loader.load_user_context(
-                        member_id, organization_id
+                        member_id, str(organization_id)
                     )
                     or {}
                 )
@@ -368,6 +371,10 @@ class StytchVerifier:
                     f"Failed to load fresh team context from cache: {str(e)}"
                 )
 
+        # Convert available_teams dicts to TeamInfo objects (v2.3.0+)
+        available_teams_data = team_context.get("available_teams", [])
+        available_teams = [TeamInfo(**team_dict) for team_dict in available_teams_data]
+
         return StytchContext(
             # Core Stytch identifiers
             member_id=member_id,
@@ -400,9 +407,12 @@ class StytchVerifier:
             entitlements=cached_data.get("entitlements"),
             subscription_tier=cached_data.get("subscription_tier"),
             subscription_limits=cached_data.get("subscription_limits"),
-            # Team context (v2.0.1+ - always loaded fresh from MongoDB)
-            current_team_id=team_context.get("current_team_id"),
-            current_team_name=team_context.get("current_team_name"),
+            # Team context (v2.3.0+)
+            available_teams=available_teams,
+            # Deprecated fields (v2.3.0+): current_team_id and current_team_name are no longer
+            # populated as users.current_team_id has been removed from MongoDB schema
+            current_team_id=None,
+            current_team_name=None,
             # MongoDB identifiers (v2.0.0+ - may be None for old cache entries)
             mongo_user_id=team_context.get("mongo_user_id")
             or cached_data.get("mongo_user_id"),
@@ -494,6 +504,10 @@ class StytchVerifier:
                 )
                 entitlements_data = {}
 
+        # Convert available_teams dicts to TeamInfo objects (v2.3.0+)
+        available_teams_data = entitlements_data.get("available_teams", [])
+        available_teams = [TeamInfo(**team_dict) for team_dict in available_teams_data]
+
         return StytchContext(
             # Core Stytch identifiers
             member_id=member_id,
@@ -526,9 +540,12 @@ class StytchVerifier:
             entitlements=entitlements_data.get("entitlements"),
             subscription_tier=entitlements_data.get("subscription_tier"),
             subscription_limits=entitlements_data.get("subscription_limits"),
-            # Team context (v2.0.0+)
-            current_team_id=entitlements_data.get("current_team_id"),
-            current_team_name=entitlements_data.get("current_team_name"),
+            # Team context (v2.3.0+)
+            available_teams=available_teams,
+            # Deprecated fields (v2.3.0+): current_team_id and current_team_name are no longer
+            # populated as users.current_team_id has been removed from MongoDB schema
+            current_team_id=None,
+            current_team_name=None,
             # MongoDB identifiers (v2.0.0+)
             mongo_user_id=entitlements_data.get("mongo_user_id"),
             mongo_organization_id=entitlements_data.get("mongo_organization_id"),
@@ -583,10 +600,10 @@ class StytchVerifier:
 
             response_json: Dict[str, Any] = {}
             try:
-                if hasattr(response, "json"):
+                if hasattr(response, "json") and callable(response.json):
                     json_data = response.json()
-                    if isinstance(json_data, dict):
-                        response_json = json_data
+                    if isinstance(json_data, dict):  # type: ignore[unreachable]
+                        response_json = json_data  # type: ignore[unreachable]
             except Exception:
                 pass  # Keep response_json as empty dict
 
