@@ -316,7 +316,7 @@ class RedisClient:
             cached_data = await client.get(cache_key)
             if cached_data:
                 logger.debug(f"Cache hit for user ID: {stytch_member_id}")
-                return cached_data
+                return str(cached_data) if cached_data else None
 
             logger.debug(f"Cache miss for user ID: {stytch_member_id}")
             return None
