@@ -3,7 +3,9 @@ Pydantic models for ayz-auth package.
 """
 
 from .context import StytchContext
+from .team import TeamInfo
 
 __all__ = [
     "StytchContext",
+    "TeamInfo",
 ]
