@@ -10,6 +10,8 @@ from typing import Any, Dict, List, Optional
 
 from pydantic import BaseModel, Field, field_serializer
 
+from .team import TeamInfo
+
 
 class StytchContext(BaseModel):
     """
@@ -84,14 +86,30 @@ class StytchContext(BaseModel):
         description="Subscription limits (e.g., {'max_projects': 10, 'max_users': 50})",
     )
 
-    # Team context data (v2.0.0+)
+    # Team context data (v2.0.0+ - DEPRECATED in v2.3.0+)
     current_team_id: Optional[str] = Field(
         default=None,
-        description="MongoDB ObjectId of user's current team (as string)",
+        deprecated=True,
+        description=(
+            "DEPRECATED in v2.3.0: This field is no longer populated as "
+            "users.current_team_id has been removed from the MongoDB schema. "
+            "Use available_teams list and has_team_access() instead."
+        ),
     )
     current_team_name: Optional[str] = Field(
         default=None,
-        description="Name of user's current team",
+        deprecated=True,
+        description=(
+            "DEPRECATED in v2.3.0: This field is no longer populated as "
+            "users.current_team_id has been removed from the MongoDB schema. "
+            "Use available_teams list instead."
+        ),
+    )
+
+    # Available teams (v2.3.0+)
+    available_teams: List[TeamInfo] = Field(
+        default_factory=list,
+        description="All teams user has access to in the current organization (v2.3.0+)",
     )
 
     # MongoDB identifiers (v2.0.0+)
@@ -137,6 +155,91 @@ class StytchContext(BaseModel):
         """Convert to dictionary for serialization."""
         return self.model_dump(mode="json")
 
+    # Team access helpers (v2.3.0+)
+    def has_team_access(self, team_id: str) -> bool:
+        """
+        Check if user has access to a specific team.
+
+        This provides O(n) lookup through the available_teams list to determine
+        if the user has access to the specified team within the current organization.
+
+        Args:
+            team_id: MongoDB ObjectId of the team (as string)
+
+        Returns:
+            True if user has access to the team, False otherwise
+
+        Example:
+            ```python
+            @router.get("/sessions")
+            async def list_sessions(
+                team_id: str = Header(..., alias="X-Current-Team-Id"),
+                auth: StytchContext = Depends(verify_auth)
+            ):
+                if not auth.has_team_access(team_id):
+                    raise HTTPException(403, "Access denied to this team")
+                sessions = await db.sessions.find({"team_id": team_id})
+                return sessions
+            ```
+        """
+        return any(team.id == team_id for team in self.available_teams)
+
+    def get_team_permissions(self, team_id: str) -> List[str]:
+        """
+        Get permissions for a specific team.
+
+        Args:
+            team_id: MongoDB ObjectId of the team (as string)
+
+        Returns:
+            List of permission strings for the team, empty list if team not found
+
+        Example:
+            ```python
+            permissions = auth.get_team_permissions(team_id)
+            if "write" not in permissions:
+                raise HTTPException(403, "Write permission required")
+            ```
+        """
+        team = next((t for t in self.available_teams if t.id == team_id), None)
+        return team.permissions if team else []
+
+    def get_team_role(self, team_id: str) -> Optional[str]:
+        """
+        Get user's role in a specific team.
+
+        Args:
+            team_id: MongoDB ObjectId of the team (as string)
+
+        Returns:
+            Role string (e.g., 'admin', 'member') if found, None otherwise
+
+        Example:
+            ```python
+            role = auth.get_team_role(team_id)
+            if role != "admin":
+                raise HTTPException(403, "Admin role required")
+            ```
+        """
+        team = next((t for t in self.available_teams if t.id == team_id), None)
+        return team.role if team else None
+
+    @property
+    def team_count(self) -> int:
+        """
+        Number of teams user has access to in the current organization.
+
+        Returns:
+            Count of available teams
+
+        Example:
+            ```python
+            if auth.team_count == 0:
+                return {"message": "No teams available"}
+            ```
+        """
+        return len(self.available_teams)
+
     def __str__(self) -> str:
         """String representation for logging (without sensitive data)."""
         expires = (
