@@ -211,51 +211,14 @@ class TestMongoClient:
     # get_user() Tests
     # =====================================================================
 
-    @pytest.mark.asyncio
-    async def test_get_user_success(
-        self, mock_mongo_client, mock_settings_with_mongodb
-    ):
-        """Test successful user retrieval."""
-        user_data = {
-            "_id": "user_mongo_id",
-            "stytch_member_id": "member-live-xyz789",
-            "current_team_id": "team_mongo_id",
-        }
-
-        mock_db = MagicMock()
-        mock_collection = AsyncMock()
-        mock_collection.find_one = AsyncMock(return_value=user_data)
-        mock_db.users = mock_collection
-
-        with patch.object(mock_mongo_client, "_get_client", return_value=mock_db):
-            result = await mock_mongo_client.get_user("member-live-xyz789")
-
-            assert result == user_data
-            mock_collection.find_one.assert_called_once_with(
-                {"stytch_member_id": "member-live-xyz789"}
-            )
-
-    @pytest.mark.asyncio
-    async def test_get_user_not_found(
-        self, mock_mongo_client, mock_settings_with_mongodb
-    ):
-        """Test user retrieval when user doesn't exist."""
-        mock_db = MagicMock()
-        mock_collection = AsyncMock()
-        mock_collection.find_one = AsyncMock(return_value=None)
-        mock_db.users = mock_collection
-
-        with patch.object(mock_mongo_client, "_get_client", return_value=mock_db):
-            result = await mock_mongo_client.get_user("member-live-nonexistent")
-
-            assert result is None
-
     @pytest.mark.asyncio
     async def test_get_user_mongodb_not_configured(
         self, mock_mongo_client, mock_settings_without_mongodb
     ):
         """Test get_user returns None when MongoDB not configured."""
-        result = await mock_mongo_client.get_user("member-live-xyz789")
+        result = await mock_mongo_client.get_user(
+            "member-live-xyz789", "organization-live-test"
+        )
         assert result is None
 
     @pytest.mark.asyncio
@@ -263,11 +226,9 @@ class TestMongoClient:
         self, mock_mongo_client, mock_settings_with_mongodb
     ):
         """Test user lookup with org context for multi-org user (primary scenario)."""
-        # User data
+        # User data (v3.0.0+: no stytch_member_id or current_team_id in users collection)
         user_data = {
             "_id": "user_mongo_id_123",
-            "stytch_member_id": "member-live-ayzenberg-abc",  # Different from Mercury ID!
-            "current_team_id": "team_mongo_id",
         }
 
         # Organization data
@@ -337,12 +298,7 @@ class TestMongoClient:
     async def test_get_user_with_org_context_org_not_found(
         self, mock_mongo_client, mock_settings_with_mongodb
     ):
-        """Test user lookup when organization doesn't exist (fallback to direct lookup)."""
-        user_data = {
-            "_id": "user_mongo_id",
-            "stytch_member_id": "member-live-xyz789",
-        }
-
+        """Test user lookup when organization doesn't exist (returns None in v3.0.0+)."""
         mock_db = MagicMock()
 
         # Mock organizations collection - org not found
@@ -350,32 +306,19 @@ class TestMongoClient:
         mock_orgs_collection.find_one = AsyncMock(return_value=None)
         mock_db.organizations = mock_orgs_collection
 
-        # Mock users collection - fallback lookup succeeds
-        mock_users_collection = AsyncMock()
-        mock_users_collection.find_one = AsyncMock(return_value=user_data)
-        mock_db.users = mock_users_collection
-
         with patch.object(mock_mongo_client, "_get_client", return_value=mock_db):
             result = await mock_mongo_client.get_user(
                 "member-live-xyz789", "organization-live-nonexistent"
             )
 
-            # Should fall back to direct user lookup
-            assert result == user_data
-            mock_users_collection.find_one.assert_called_once_with(
-                {"stytch_member_id": "member-live-xyz789"}
-            )
+            # v3.0.0+: No fallback, returns None when org not found
+            assert result is None
 
     @pytest.mark.asyncio
     async def test_get_user_with_org_context_no_membership(
         self, mock_mongo_client, mock_settings_with_mongodb
     ):
-        """Test user lookup when user has no org membership (fallback to direct lookup)."""
-        user_data = {
-            "_id": "user_mongo_id",
-            "stytch_member_id": "member-live-xyz789",
-        }
-
+        """Test user lookup when user has no org membership (returns None in v3.0.0+)."""
         org_data = {
             "_id": "org_mongo_id",
             "stytch_org_id": "organization-live-abc123",
@@ -393,58 +336,19 @@ class TestMongoClient:
         mock_memberships_collection.find_one = AsyncMock(return_value=None)
         mock_db.user_organization_memberships = mock_memberships_collection
 
-        # Mock users collection - fallback lookup succeeds
-        mock_users_collection = AsyncMock()
-        mock_users_collection.find_one = AsyncMock(return_value=user_data)
-        mock_db.users = mock_users_collection
-
         with patch.object(mock_mongo_client, "_get_client", return_value=mock_db):
             result = await mock_mongo_client.get_user(
                 "member-live-xyz789", "organization-live-abc123"
             )
 
-            # Should fall back to direct user lookup
-            assert result == user_data
-            mock_users_collection.find_one.assert_called_once_with(
-                {"stytch_member_id": "member-live-xyz789"}
-            )
-
-    @pytest.mark.asyncio
-    async def test_get_user_single_org_user_backwards_compatibility(
-        self, mock_mongo_client, mock_settings_with_mongodb
-    ):
-        """Test backwards compatibility: single-org user without org context."""
-        user_data = {
-            "_id": "user_mongo_id",
-            "stytch_member_id": "member-live-xyz789",
-            "current_team_id": "team_mongo_id",
-        }
-
-        mock_db = MagicMock()
-        mock_collection = AsyncMock()
-        mock_collection.find_one = AsyncMock(return_value=user_data)
-        mock_db.users = mock_collection
-
-        with patch.object(mock_mongo_client, "_get_client", return_value=mock_db):
-            # Call without org_id (backwards compatibility)
-            result = await mock_mongo_client.get_user("member-live-xyz789")
-
-            # Should use direct user lookup (fallback)
-            assert result == user_data
-            mock_collection.find_one.assert_called_once_with(
-                {"stytch_member_id": "member-live-xyz789"}
-            )
+            # v3.0.0+: No fallback, returns None when no membership found
+            assert result is None
 
     @pytest.mark.asyncio
     async def test_get_user_with_org_context_membership_has_no_user_id(
         self, mock_mongo_client, mock_settings_with_mongodb
     ):
         """Test user lookup when org membership exists but has no user_id (data integrity issue)."""
-        user_data = {
-            "_id": "user_mongo_id",
-            "stytch_member_id": "member-live-xyz789",
-        }
-
         org_data = {
             "_id": "org_mongo_id",
             "stytch_org_id": "organization-live-abc123",
@@ -473,22 +377,13 @@ class TestMongoClient:
         )
         mock_db.user_organization_memberships = mock_memberships_collection
 
-        # Mock users collection - fallback lookup succeeds
-        mock_users_collection = AsyncMock()
-        mock_users_collection.find_one = AsyncMock(return_value=user_data)
-        mock_db.users = mock_users_collection
-
         with patch.object(mock_mongo_client, "_get_client", return_value=mock_db):
             result = await mock_mongo_client.get_user(
                 "member-live-xyz789", "organization-live-abc123"
             )
 
-            # Should fall back to direct user lookup
-            assert result == user_data
-            # Verify fallback was called with correct stytch_member_id
-            assert mock_users_collection.find_one.call_count == 1
-            call_args = mock_users_collection.find_one.call_args[0][0]
-            assert call_args == {"stytch_member_id": "member-live-xyz789"}
+            # v3.0.0+: Returns None when membership has no user_id (data integrity issue)
+            assert result is None
 
     # =====================================================================
     # get_team() Tests
